### Progressive Shortening and General Improvements in Tool Responses

March 21, 2026

Tools that may deliver too long results now output informative shorter messages instead of just stating "result is too long". The mechanism uses progressive shortening so that the contained information is optimized for the length limit.

In addition, several tool responses have been optimized without losing content, making Serena even more token efficient in general.